@@ -21,7 +21,7 @@ class Build(Command):
     Build a project in the current directory and produce a ready-to-upload
     firmware file.
 
-    The project is expected to have `src' subdirectroy where all its sources
+    The project is expected to have a `src' subdirectroy where all its sources
     are located. This directory is scanned recursively to find
     *.[c|cpp|pde|ino] files. They are compiled and linked into resulting
     firmware hex-file.
